You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@camel.apache.org by da...@apache.org on 2017/06/24 07:50:42 UTC

[1/4] camel git commit: CAMEL-11442: Optimise - Use existing exchange id as breadcrumb

Repository: camel
Updated Branches:
  refs/heads/master 329700289 -> 37544131a


CAMEL-11442: Optimise - Use existing exchange id as breadcrumb


Project: http://git-wip-us.apache.org/repos/asf/camel/repo
Commit: http://git-wip-us.apache.org/repos/asf/camel/commit/cf6e3517
Tree: http://git-wip-us.apache.org/repos/asf/camel/tree/cf6e3517
Diff: http://git-wip-us.apache.org/repos/asf/camel/diff/cf6e3517

Branch: refs/heads/master
Commit: cf6e35178d0bb28eac74402a7d3da8d7a6d9e48b
Parents: 3297002
Author: Claus Ibsen <da...@apache.org>
Authored: Sat Jun 24 09:39:20 2017 +0200
Committer: Claus Ibsen <da...@apache.org>
Committed: Sat Jun 24 09:39:20 2017 +0200

----------------------------------------------------------------------
 .../org/apache/camel/spring/SpringMDCWithBreadcrumbTest.java     | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/camel/blob/cf6e3517/components/camel-spring/src/test/java/org/apache/camel/spring/SpringMDCWithBreadcrumbTest.java
----------------------------------------------------------------------
diff --git a/components/camel-spring/src/test/java/org/apache/camel/spring/SpringMDCWithBreadcrumbTest.java b/components/camel-spring/src/test/java/org/apache/camel/spring/SpringMDCWithBreadcrumbTest.java
index 7c79281..256b12a 100644
--- a/components/camel-spring/src/test/java/org/apache/camel/spring/SpringMDCWithBreadcrumbTest.java
+++ b/components/camel-spring/src/test/java/org/apache/camel/spring/SpringMDCWithBreadcrumbTest.java
@@ -37,7 +37,7 @@ public class SpringMDCWithBreadcrumbTest extends SpringMDCTest {
         public void process(Exchange exchange) throws Exception {
             assertEquals("route-a", MDC.get("camel.routeId"));
             assertEquals(exchange.getExchangeId(), MDC.get("camel.exchangeId"));
-            assertEquals(exchange.getIn().getMessageId(), MDC.get("camel.breadcrumbId"));
+            assertEquals(exchange.getExchangeId(), MDC.get("camel.breadcrumbId"));
         }
     }
 
@@ -45,7 +45,7 @@ public class SpringMDCWithBreadcrumbTest extends SpringMDCTest {
 
         public void process(Exchange exchange) throws Exception {
             assertEquals("route-b", MDC.get("camel.routeId"));
-            assertEquals(exchange.getIn().getMessageId(), MDC.get("camel.breadcrumbId"));
+            assertEquals(exchange.getExchangeId(), MDC.get("camel.breadcrumbId"));
         }
     }
 


[3/4] camel git commit: Optimise - Small optimisation in type converter

Posted by da...@apache.org.
Optimise - Small optimisation in type converter


Project: http://git-wip-us.apache.org/repos/asf/camel/repo
Commit: http://git-wip-us.apache.org/repos/asf/camel/commit/b4f21f90
Tree: http://git-wip-us.apache.org/repos/asf/camel/tree/b4f21f90
Diff: http://git-wip-us.apache.org/repos/asf/camel/diff/b4f21f90

Branch: refs/heads/master
Commit: b4f21f9037a61fe47036e7baf3c09499f32e589a
Parents: 710e9b3
Author: Claus Ibsen <da...@apache.org>
Authored: Sat Jun 24 09:46:41 2017 +0200
Committer: Claus Ibsen <da...@apache.org>
Committed: Sat Jun 24 09:46:41 2017 +0200

----------------------------------------------------------------------
 .../org/apache/camel/impl/converter/BaseTypeConverterRegistry.java | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/camel/blob/b4f21f90/camel-core/src/main/java/org/apache/camel/impl/converter/BaseTypeConverterRegistry.java
----------------------------------------------------------------------
diff --git a/camel-core/src/main/java/org/apache/camel/impl/converter/BaseTypeConverterRegistry.java b/camel-core/src/main/java/org/apache/camel/impl/converter/BaseTypeConverterRegistry.java
index 5e0ccf0..6e4a1b1 100644
--- a/camel-core/src/main/java/org/apache/camel/impl/converter/BaseTypeConverterRegistry.java
+++ b/camel-core/src/main/java/org/apache/camel/impl/converter/BaseTypeConverterRegistry.java
@@ -272,7 +272,7 @@ public abstract class BaseTypeConverterRegistry extends ServiceSupport implement
         }
 
         // special for NaN numbers, which we can only convert for floating numbers
-        if (value.equals(Float.NaN) || value.equals(Double.NaN) ) {
+        if (value instanceof Number && (value.equals(Float.NaN) || value.equals(Double.NaN))) {
             // no type conversion was needed
             if (statistics.isStatisticsEnabled()) {
                 noopCounter.increment();


[2/4] camel git commit: Regen

Posted by da...@apache.org.
Regen


Project: http://git-wip-us.apache.org/repos/asf/camel/repo
Commit: http://git-wip-us.apache.org/repos/asf/camel/commit/710e9b30
Tree: http://git-wip-us.apache.org/repos/asf/camel/tree/710e9b30
Diff: http://git-wip-us.apache.org/repos/asf/camel/diff/710e9b30

Branch: refs/heads/master
Commit: 710e9b300e3e6418ae96004dc9c4d711a72ba898
Parents: cf6e351
Author: Claus Ibsen <da...@apache.org>
Authored: Sat Jun 24 09:39:32 2017 +0200
Committer: Claus Ibsen <da...@apache.org>
Committed: Sat Jun 24 09:39:32 2017 +0200

----------------------------------------------------------------------
 components/readme.adoc         | 5 ++++-
 docs/user-manual/en/SUMMARY.md | 1 +
 2 files changed, 5 insertions(+), 1 deletion(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/camel/blob/710e9b30/components/readme.adoc
----------------------------------------------------------------------
diff --git a/components/readme.adoc b/components/readme.adoc
index edb2e72..a7005c3 100644
--- a/components/readme.adoc
+++ b/components/readme.adoc
@@ -2,7 +2,7 @@ Components
 ^^^^^^^^^^
 
 // components: START
-Number of Components: 274 in 188 JAR artifacts (17 deprecated)
+Number of Components: 275 in 189 JAR artifacts (17 deprecated)
 
 [width="100%",cols="4,1,5",options="header"]
 |=======================================================================
@@ -761,6 +761,9 @@ Number of Components: 274 in 188 JAR artifacts (17 deprecated)
 | link:../camel-core/src/main/docs/test-component.adoc[Test] (camel-core) +
 `test:name` | 1.3 | The test component extends the mock component by on startup to pull messages from another endpoint to set the expected message bodies.
 
+| link:camel-thrift/src/main/docs/thrift-component.adoc[Thrift] (camel-thrift) +
+`thrift:host:port/service` | 2.20 | The Thrift component allows to call and expose remote procedures (RPC) with Apache Thrift data format and serialization mechanism
+
 | link:camel-tika/src/main/docs/tika-component.adoc[Tika] (camel-tika) +
 `tika:operation` | 2.19 | This component integrates with Apache Tika to extract content and metadata from thousands of file types.
 

http://git-wip-us.apache.org/repos/asf/camel/blob/710e9b30/docs/user-manual/en/SUMMARY.md
----------------------------------------------------------------------
diff --git a/docs/user-manual/en/SUMMARY.md b/docs/user-manual/en/SUMMARY.md
index 0470809..39447fc 100644
--- a/docs/user-manual/en/SUMMARY.md
+++ b/docs/user-manual/en/SUMMARY.md
@@ -354,6 +354,7 @@
 	* [Stream](stream-component.adoc)
 	* [String Template](string-template-component.adoc)
 	* [Telegram](telegram-component.adoc)
+	* [Thrift](thrift-component.adoc)
 	* [Tika](tika-component.adoc)
 	* [Twilio](twilio-component.adoc)
 	* [Twitter](twitter-component.adoc)


[4/4] camel git commit: Fixed test now that camel-docker works in OSGi

Posted by da...@apache.org.
Fixed test now that camel-docker works in OSGi


Project: http://git-wip-us.apache.org/repos/asf/camel/repo
Commit: http://git-wip-us.apache.org/repos/asf/camel/commit/37544131
Tree: http://git-wip-us.apache.org/repos/asf/camel/tree/37544131
Diff: http://git-wip-us.apache.org/repos/asf/camel/diff/37544131

Branch: refs/heads/master
Commit: 37544131a08665e1eeb205db63e83bd55149af9f
Parents: b4f21f9
Author: Claus Ibsen <da...@apache.org>
Authored: Sat Jun 24 09:50:35 2017 +0200
Committer: Claus Ibsen <da...@apache.org>
Committed: Sat Jun 24 09:50:35 2017 +0200

----------------------------------------------------------------------
 .../org/apache/camel/catalog/karaf/KarafRuntimeProviderTest.java | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/camel/blob/37544131/platforms/camel-catalog-provider-karaf/src/test/java/org/apache/camel/catalog/karaf/KarafRuntimeProviderTest.java
----------------------------------------------------------------------
diff --git a/platforms/camel-catalog-provider-karaf/src/test/java/org/apache/camel/catalog/karaf/KarafRuntimeProviderTest.java b/platforms/camel-catalog-provider-karaf/src/test/java/org/apache/camel/catalog/karaf/KarafRuntimeProviderTest.java
index 74425de..c6bfa8a 100644
--- a/platforms/camel-catalog-provider-karaf/src/test/java/org/apache/camel/catalog/karaf/KarafRuntimeProviderTest.java
+++ b/platforms/camel-catalog-provider-karaf/src/test/java/org/apache/camel/catalog/karaf/KarafRuntimeProviderTest.java
@@ -62,8 +62,8 @@ public class KarafRuntimeProviderTest {
 
         assertTrue(names.contains("ftp"));
         assertTrue(names.contains("paxlogging"));
-        // camel-docker does not work in Karaf
-        assertFalse(names.contains("docker"));
+        // camel-ejb does not work in Karaf
+        assertFalse(names.contains("ejb"));
     }
 
     @Test